@@ -102,13 +102,15 @@ async def generate(request: ImageRequest, n: int = 30):  # 兼容dalle3
 
 # VideoResult
 if __name__ == '__main__':
-    api_key = "88b82799f3234a5aad130b0f74c7eb85.tBMTRh0h1IqbvMaw"
+    api_key = "a7eb02770d1a41be95ba0b82f651e761.gHEXdCbRLadIwKtI"
+
+    ""
     # api_key = "7d10426c06afa81e8d7401d97781249c.DbqlSsicRtaUdKXI"  # 新号
     # api_key = "e21bd630f681c4d90b390cd609720483.WSFVgA3Kk1wNCX0mN"
 
     request = VideoRequest(
-        model='cogvideox-flash',
-        # model='cogvideox'
+        # model='cogvideox-flash',
+        model='cogvideox'
 
     )
     r = arun(create_task(request, api_key=api_key))
