@@ -17,6 +17,8 @@ from meutils.schemas.image_types import ImageRequest
 from meutils.apis.fal.images import generate as fal_generate
 
 from meutils.apis.gitee.image_to_3d import generate as image_to_3d_generate
+from meutils.apis.gitee.openai_images import generate as gitee_images_generate
+
 
 async def generate(
         request: ImageRequest,
@@ -33,6 +35,12 @@ async def generate(
     if request.model in {"Hunyuan3D-2", "Hi3DGen", "Step1X-3D"}:
         return await image_to_3d_generate(request, api_key)
 
+    if request.model in {"Qwen-Image", "FLUX_1-Krea-dev"}:
+        return await gitee_images_generate(request, api_key)
+
+
+# "flux.1-krea-dev"
 
 if __name__ == '__main__':
-    arun(generate(ImageRequest(model="flux", prompt="笑起来")))
+    # arun(generate(ImageRequest(model="flux", prompt="笑起来")))
+    arun(generate(ImageRequest(model="FLUX_1-Krea-dev", prompt="笑起来")))
