@@ -42,7 +42,7 @@ async def create_draft_content(request: ImageRequest, token: str):
     创建草稿内容
     """
     # 参考人物
-    face_recognize_data = request.controls.get("face_recognize_data", {})
+    face_recognize_data = (request.controls or {}).get("face_recognize_data", {})
     image_uri = face_recognize_data.pop("image_uri", None)
 
     request.model = MODELS_MAP.get(request.model, MODELS_MAP["default"])
