@@ -202,7 +202,7 @@ if __name__ == "__main__":
         prompt="无人机以极快速度穿越复杂障碍或自然奇观，带来沉浸式飞行体验",
         duration=10
     )
-    r = arun(create_task(request))
+    # r = arun(create_task(request))
     # r = {'id': 'cgt-20250612172542-6nbt2'}
 
     # arun(get_task(r.get('id')))
@@ -211,7 +211,7 @@ if __name__ == "__main__":
 
     # arun(get_task("cgt-20250707160713-j8kll"))
 
-    # arun(get_valid_token())
+    arun(get_valid_token())
 
 """
 {'id': 'cgt-20250613160030-2dvd7',
