@@ -279,13 +279,19 @@ async def check_token_for_volc(api_key, threshold: float = 1, purpose: Optional[
 @retrying()
 async def check_token_for_zhipu(api_key, threshold: float = 1, resource_package_name: Optional[str] = None):
     if not isinstance(api_key, str):
-        return await check_tokens(api_key, check_token_for_ppinfra)
+        return await check_tokens(
+            api_key,
+            partial(check_token_for_zhipu, threshold=threshold, resource_package_name=resource_package_name)
+        )
     try:
         client = AsyncOpenAI(base_url="https://bigmodel.cn/api/biz/tokenAccounts/list", api_key=api_key)
         data = await client.get("", cast_to=object)
         logger.debug(bjson(data))
 
         if resource_package_name:
+            # print(str(data))
+            # if """glm-4.5""" not in str(data): return False
+
             # "resourcePackageName": "【新用户专享】200万通用模型资源包",
             # "resourcePackageName": "【新用户专享】400次图像、视频生成、搜索工具次包",
             # "resourcePackageName": "【新用户专享】200万通用模型资源包",
@@ -293,7 +299,7 @@ async def check_token_for_zhipu(api_key, threshold: float = 1, resource_package_
             # "resourcePackageName": "【新用户专享】30次Vidu系列视频生成次包",
             for d in data["rows"]:
                 if resource_package_name.lower() in d["resourcePackageName"].lower():
-                    logger.debug(bjson(d))
+                    # logger.debug(bjson(d))
                     return d["tokenBalance"] >= threshold
         else:
             logger.debug(bjson(data))
@@ -307,14 +313,6 @@ async def check_token_for_zhipu(api_key, threshold: float = 1, resource_package_
         return False
 
 
-# curl 'https://bigmodel.cn/api/biz/product/createPreOrder' \
-#   -H 'accept: application/json, text/plain, */*' \
-#   -H 'accept-language: zh' \
-#   -H 'authorization: eyJhbGciOiJIUzUxMiJ9.eyJ1c2VyX3R5cGUiOiJQRVJTT05BTCIsInVzZXJfaWQiOjIyNDAwNDUsInVzZXJfa2V5IjoiNTZmNjkxODUtOTBhMS00NDYyLWFhNWYtYTljNjhmMGY0Njc3IiwiY3VzdG9tZXJfaWQiOiI2MTQ2MTc1MjExNDcxMTYwNSIsInVzZXJuYW1lIjoia2JieHYxMDYifQ.3zLefwa8lzQLyNYz0DVqkgdOgm1_ljPEoihza44Wv1r-pEPS08kQFeZm-v2CY3qhslgHh2I3d1LN_mr-9bhQjw' \
-#   -
-#   -H 'user-agent: Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/138.0.0.0 Safari/537.36' \
-#   --data-raw '{"channelCode":"BALANCE","isMobile":false,"num":1,"payPrice":0,"productId":"product-e6e499"}'
-
 @retrying()
 @rcache(ttl=1 * 24 * 3600, skip_cache_func=skip_cache_func)
 async def check_token_for_fal(token, threshold: float = 0):
@@ -405,8 +403,7 @@ if __name__ == '__main__':
 
     # arun(check_token_for_ppinfra("sk_mCb5sRGTi6GXkSRp5F679Rbs0V_Hfee3p85lccGXCOo"))
 
-    # arun(check_token_for_zhipu(api_key="e130b903ab684d4fad0d35e411162e99.PqyXq4QBjfTdhyCh",
-    #                            resource_package_name='vidu'))
+    arun(check_token_for_zhipu(api_key="e130b903ab684d4fad0d35e411162e99.PqyXq4QBjfTdhyCh"))
 
     # arun(check_token_for_fal("56d8a95e-2fe6-44a6-8f7d-f7f9c83eec24:537f06b6044770071f5d86fc7fcd6d6f"))
 
