@@ -37,7 +37,7 @@ class Completions(object):
 
         ###########################################################################
         # 开启视觉模型
-        if not any(i in request.model.lower() for i in ["vl", 'vision', 'doubao-seed']) and (
+        if not any(i in request.model.lower() for i in ["v-", "vl", 'vision', 'doubao-seed']) and (
                 urls := request.last_urls.get("image_url")):
             # logger.debug(request)
             if request.model.startswith(("gemini",)):
@@ -75,7 +75,7 @@ class Completions(object):
 
         elif "deepseek-r" in request.model:
             request.separate_reasoning = True  # pp
-            """Error code: 403 - {'code': 403, 'reason': 'NOT_ENOUGH_BALANCE', 'message': 'not enough balance', 'metadata': {}}"""
+            # """Error code: 403 - {'code': 403, 'reason': 'NOT_ENOUGH_BALANCE', 'message': 'not enough balance', 'metadata': {}}"""
         ###########################################################################
 
         data = to_openai_params(request)
