@@ -20,7 +20,7 @@ MJ_RELAX = 1
 MJ_FAST = 1.5
 
 STEP = 2
-MINIMAX_VIDEO = 3
+MINIMAX_VIDEO = 2 * 0.6
 
 FAL = 3
 FAL_ = 5
@@ -81,6 +81,7 @@ FAL_MODELS = {
 
     # veo
     "fal-ai/veo3/fast": 3.2 * FAL_,  # 2 3.2
+    "fal-ai/veo3/fast/image-to-video": 3.2 * FAL_,
 
     # seedance
     "fal-ai/bytedance/seedance/v1/lite/text-to-video": 1,
@@ -106,7 +107,7 @@ FAL_MODELS = {
 MODEL_PRICE = {
     **FAL_MODELS,
 
-    "qwen-image": 0.15,
+    "qwen-image": 0.1,
 
     "wan-ai-wan2.1-t2v-14b": 1,
     "wan-ai-wan2.1-t2v-14b-turbo": 1,
@@ -141,7 +142,7 @@ MODEL_PRICE = {
     "gemini-2.5-pro-video": 0.1,
 
     # rix
-    "kling_image": 0.05,
+    "kling_image": 0.025,
     "kling_image_expand": 0.3,
     "kling_virtual_try_on": 1,
     "kling_effects": 1,
@@ -167,6 +168,7 @@ MODEL_PRICE = {
     # 火山
     "jimeng-video-3.0": 0.5,
     "doubao-seedream-3-0-t2i-250415": 0.1,
+    "doubao-seededit-3-0-i2i-250628": 0.1,
 
     "doubao-seedance-1-0-pro-250528": 0.5,  # 480 1080
     "api-doubao-seedance-1-0-pro-250528-1080p": 2,  # 480 1080
@@ -184,13 +186,25 @@ MODEL_PRICE = {
     "veo3-pro": 8,
     "veo3-pro-frames": 8,
 
-    # hailuo
+    # hailuo https://www.minimax.io/price
     "minimax-hailuo-02": 1,
     "api-minimax-hailuo-01-6s": 0.5,
     "api-minimax-hailuo-02-6s-768p": 1,
     "api-minimax-hailuo-02-10s-768p": 2,
     "api-minimax-hailuo-02-6s-1080p": 2,
 
+    "minimax-t2v-01_6s_720p": 1 * MINIMAX_VIDEO,
+    "minimax-t2v-01-director_6s_720p": 1 * MINIMAX_VIDEO,
+    "minimax-i2v-01_6s_720p": 1 * MINIMAX_VIDEO,
+    "minimax-i2v-01-director_6s_720p": 1 * MINIMAX_VIDEO,
+    "minimax-i2v-01-live_6s_720p": 1 * MINIMAX_VIDEO,
+    "minimax-s2v-01_6s_720p": 1.5 * MINIMAX_VIDEO,
+    "minimax-hailuo-02_6s_512p": 0.3 * MINIMAX_VIDEO,
+    "minimax-hailuo-02_10s_512p": 0.5 * MINIMAX_VIDEO,
+    "minimax-hailuo-02_6s_768p": 1 * MINIMAX_VIDEO,
+    "minimax-hailuo-02_10s_768p": 2 * MINIMAX_VIDEO,
+    "minimax-hailuo-02_6s_1080p": 2 * MINIMAX_VIDEO,
+
     # chatfire
     "ppu-01": 0.01,
     "ppu-1": 0.1,
@@ -236,7 +250,7 @@ MODEL_PRICE = {
     "cogvideox-flash": 0.05,
     "cogvideox": 0.1,
     "cogvideox-2": 0.2,
-    "cogvideox-3": 0.5,
+    "cogvideox-3": 0.3,
     "cogvideox-3-flash": 0.1,
 
     "official-api-cogvideox": 0.1,
@@ -310,6 +324,7 @@ MODEL_PRICE = {
     "flux-pro-max": 0.1,
     "flux.1.1-pro": 0.1,
     "flux1.1-pro": 0.1,
+    "flux.1-krea-dev": 0.1,
     "black-forest-labs/flux.1.1-pro": 0.1,
 
     "step-1x-medium": 0.2,
@@ -410,6 +425,8 @@ MODEL_PRICE = {
     "gpt-4o-image": 0.05,
     "sora-image": 0.1,
     "gpt-image-1": 0.1,
+    "gpt-5-all": 0.05,
+    "gpt-5-thinking": 0.05,
 
     "gpt-4-gizmo-*": 0.1,
     "advanced-voice": 1,
@@ -621,6 +638,7 @@ MODEL_RATIO = {
     "kimi-dev-72b": 1,
     "moonshotai/kimi-k2-instruct": 2,
     "kimi-k2-0711-preview": 2,
+    "kimi-k2-turbo-preview": 2,
 
     # 智谱 https://www.bigmodel.cn/pricing
     'glm-4-9b-chat': 0.1,
@@ -651,8 +669,9 @@ MODEL_RATIO = {
     "glm-4.5-flash": 0.1,
     "glm-4.5-air": 0.2,
     "glm-4.5-airx": 1,
-    "glm-4.5": 0.5,
+    "glm-4.5": 1,
     "glm-4.5-x": 2,
+    "glm-4.5v": 1,
 
     # 阿里千问 https://dashscope.console.aliyun.com/billing
     "qwen-long": 0.25,
@@ -847,6 +866,7 @@ MODEL_RATIO = {
     "doubao-1-5-pro-256k-250115": 2.5,
     "doubao-1-5-vision-pro-32k": 1.5,
     "doubao-1-5-vision-pro-32k-250115": 1.5,
+    "doubao-1-5-pro-32k-character-250715": 0.4,
 
     "doubao-lite-128k": 0.4,
     "doubao-lite-32k": 0.15,
@@ -965,6 +985,7 @@ MODEL_RATIO = {
     "claude-sonnet-4-20250514-thinking": 1.5,
     "claude-opus-4-20250514": 7.5,
     "claude-opus-4-20250514-thinking": 7.5,
+    "claude-opus-4.1": 7.5,
 
     "deepclaude": 1.5,
     "deep-claude": 1.5,
@@ -1009,6 +1030,7 @@ MODEL_RATIO = {
     "gemini-2.0-flash-thinking-exp-1219": 0.075,
     "gemini-2.0-flash-thinking-exp-01-21": 0.075,
     "gemini-2.5-flash": 0.15,
+    "gemini-2.5-flash-nothinking": 0.06,
     "gemini-2.5-flash-preview-05-20": 0.075,
     "gemini-2.5-flash-preview-05-20-nothinking": 0.075,
 
@@ -1059,8 +1081,6 @@ MODEL_RATIO = {
     "gpt-4-1106-vision-preview": 5,
     "gpt-4-32k": 30,
     "gpt-4-32k-0613": 30,
-    "gpt-4-all": 15,
-    "gpt-4-gizmo-*": 15,
     "gpt-4-turbo": 5,
     "gpt-4-turbo-2024-04-09": 5,
     "gpt-4-turbo-preview": 5,
@@ -1094,6 +1114,14 @@ MODEL_RATIO = {
     "gpt-oss-20b": 0.025,
     "gpt-oss-120b": 0.05,
 
+    "gpt-5": 0.625,
+    "gpt-5-2025-08-07": 0.625,
+    "gpt-5-chat-latest": 0.625,
+    "gpt-5-mini": 0.125,
+    "gpt-5-mini-2025-08-07": 0.125,
+    "gpt-5-nano": 0.025,
+    "gpt-5-nano-2025-08-07": 0.025,
+
     "o1": 7.5,
     "o1-2024-12-17": 7.5,
 
@@ -1193,6 +1221,7 @@ COMPLETION_RATIO = {
     "kimi-vl-a3b-thinking": 5,
     "moonshotai/kimi-k2-instruct": 4,
     "kimi-k2-0711-preview": 4,
+    "kimi-k2-turbo-preview": 4,
 
     "moonshot-v1-8k": 5,
     "moonshot-v1-32k": 4,
@@ -1217,9 +1246,6 @@ COMPLETION_RATIO = {
     "grok-3-mini-fast-beta": 4 / 0.6,
     "grok-4": 5,
 
-    "gpt-4-all": 4,
-    "gpt-4-gizmo-*": 4,
-    "gpt-4o-all": 4,
     "gpt-4.5-preview-2025-02-27": 2,
 
     "o1-mini": 4,
@@ -1254,6 +1280,14 @@ COMPLETION_RATIO = {
     "gpt-oss-20b": 4,
     "gpt-oss-120b": 4,
 
+    "gpt-5": 8,
+    "gpt-5-2025-08-07": 8,
+    "gpt-5-chat-latest": 8,
+    "gpt-5-mini": 8,
+    "gpt-5-mini-2025-08-07": 8,
+    "gpt-5-nano": 4,
+    "gpt-5-nano-2025-08-07": 4,
+
     # claude
     "claude-3-5-haiku-20241022": 5,
     "anthropic/claude-3-5-haiku-20241022:beta": 5,
@@ -1273,6 +1307,7 @@ COMPLETION_RATIO = {
     "claude-sonnet-4-20250514-thinking": 5,
     "claude-opus-4-20250514": 5,
     "claude-opus-4-20250514-thinking": 5,
+    "claude-opus-4.1": 5,
 
     "llama-3.1-70b-instruct": 2,
     "meta-llama/Meta-Llama-3.1-70B-Instruct": 2,
@@ -1343,7 +1378,8 @@ COMPLETION_RATIO = {
 
     "gemini-2.0-flash-lite-preview-02-05": 4,
     "gemini-2.5-flash-preview-04-17": 4,
-    "gemini-2.5-flash": 8.33,
+    "gemini-2.5-flash": 8.4,
+    "gemini-2.5-flash-nothinking": 8.4,
 
     "gemini-2.0-pro": 5,
     "gemini-2.0-pro-exp": 5,
@@ -1361,8 +1397,8 @@ COMPLETION_RATIO = {
 
     "gemini-2.5-flash-preview-04-17-thinking": 23,
     "gemini-2.5-flash-preview-05-20-thinking": 23,
-    "gemini-2.5-flash-preview-05-20": 8.33333,
-    "gemini-2.5-flash-preview-05-20-nothinking": 8.33333,
+    "gemini-2.5-flash-preview-05-20": 8.4,
+    "gemini-2.5-flash-preview-05-20-nothinking": 8.4,
     "gemini-2.5-pro-think": 4,
 
     "gemini-2.5-pro-thinking": 4,
@@ -1443,6 +1479,7 @@ COMPLETION_RATIO = {
 
     "doubao-1-5-ui-tars-250428": 3.43,
     "ui-tars-72b": 4,
+    "doubao-1-5-pro-32k-character-250715": 2.5,
 
     "doubao-lite-128k": 3,
     "doubao-lite-32k": 2,
@@ -1554,6 +1591,7 @@ COMPLETION_RATIO = {
     "glm-4.5-airx": 3,
     "glm-4.5": 4,
     "glm-4.5-x": 4,
+    "glm-4.5v": 3,
 
     "step-1-flash": 5,
     "step-1-8k": 5,
@@ -1778,3 +1816,6 @@ if __name__ == '__main__':
 
     print("FAL按次")
     print(','.join(FAL_MODELS))  # fal 按次
+
+    print('\n\n')
+    print([k for k in MODEL_PRICE if k.startswith(('minimax-'))] | xjoin(","))
